@@ -3,7 +3,16 @@
 from hammurabi.config import config
 from hammurabi.law import Law
 from hammurabi.pillar import Pillar
+from hammurabi.preconditions.attributes import (
+    HasMode,
+    HasNoMode,
+    IsNotOwnedBy,
+    IsOwnedBy,
+)
 from hammurabi.preconditions.base import Precondition
+from hammurabi.preconditions.directories import IsDirectoryExists, IsDirectoryNotExists
+from hammurabi.preconditions.files import IsFileExists, IsFileNotExists
+from hammurabi.preconditions.text import IsLineExists, IsLineNotExists
 from hammurabi.reporters.base import Reporter
 from hammurabi.reporters.json import JSONReporter
 from hammurabi.rules.attributes import ModeChanged, OwnerChanged
@@ -28,6 +37,13 @@ from hammurabi.rules.ini import (
     SectionNotExists,
     SectionRenamed,
 )
+from hammurabi.rules.json import (
+    JSONKeyExists,
+    JSONKeyNotExists,
+    JSONKeyRenamed,
+    JSONValueExists,
+    JSONValueNotExists,
+)
 from hammurabi.rules.operations import Copied, Moved, Renamed
 from hammurabi.rules.templates import TemplateRendered
 from hammurabi.rules.text import LineExists, LineNotExists, LineReplaced
@@ -39,4 +55,4 @@ from hammurabi.rules.yaml import (
     YAMLValueNotExists,
 )
 
-__version__ = "0.5.0"
+__version__ = "0.6.0"
